==> layout-7.2.6-sources.jar: com/itextpdf/layout/layout/RootLayoutArea.java <==
/*

    This file is part of the iText (R) project.
    Copyright (c) 1998-2024 Apryse Group NV
    Authors: Bruno Lowagie, Paulo Soares, et al.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License version 3
    as published by the Free Software Foundation with the addition of the
    following permission added to Section 15 as permitted in Section 7(a):
    FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY
    ITEXT GROUP. ITEXT GROUP DISCLAIMS THE WARRANTY OF NON INFRINGEMENT
    OF THIRD PARTY RIGHTS

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
    or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU Affero General Public License for more details.
    You should have received a copy of the GNU Affero General Public License
    along with this program; if not, see http://www.gnu.org/licenses or write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA, 02110-1301 USA, or download the license from the following URL:
    http://itextpdf.com/terms-of-use/

    The interactive user interfaces in modified source and object code versions
    of this program must display Appropriate Legal Notices, as required under
    Section 5 of the GNU Affero General Public License.

    In accordance with Section 7(b) of the GNU Affero General Public License,
    a covered work must retain the producer line in every PDF that is created
    or manipulated using iText.

    You can be released from the requirements of the license by purchasing
    a commercial license. Buying such a license is mandatory as soon as you
    develop commercial activities involving the iText software without
    disclosing the source code of your own applications.
    These activities include: offering paid services to customers as an ASP,
    serving PDFs on the fly in a web application, shipping iText with a closed
    source product.

    For more information, please contact iText Software Corp. at this
    address: sales@itextpdf.com
 */
package com.itextpdf.layout.layout;

import com.itextpdf.kernel.geom.Rectangle;

/**
 * Represents the root layout area.
 */
public class RootLayoutArea extends LayoutArea implements Cloneable {
    /**
     * Indicates whether the area already has some placed content or not.
     */
    protected boolean emptyArea = true;

    /**
     * Creates the root layout area.
     *
     * @param pageNumber the value number of page
     * @param bBox the bounding box
     */
    public RootLayoutArea(int pageNumber, Rectangle bBox) {
        super(pageNumber, bBox);
    }

    /**
     * Indicates whether the area already has some placed content or not.
     *
     * @return whether the area is empty or not
     */
    public boolean isEmptyArea() {
        return emptyArea;
    }

    /**
     * Defines whether the area already has some placed content or not.
     *
     * @param emptyArea indicates whether the area already has some placed content or not.
     */
    public void setEmptyArea(boolean emptyArea) {
        this.emptyArea = emptyArea;
    }

    /**
     * Creates a "deep copy" of this RootLayoutArea, meaning the object returned by this method will be independent
     * of the object being cloned.
     * Note that although the return type of this method is {@link LayoutArea},
     * the actual type of the returned object is {@link RootLayoutArea}.
     *
     * @return the copied RootLayoutArea.
     */
    @Override
    public LayoutArea clone() {
        RootLayoutArea area = (RootLayoutArea) super.clone();
        area.setEmptyArea(emptyArea);
        return area;
    }
}

==> layout-9.0.0-sources.jar: com/itextpdf/layout/layout/RootLayoutArea.java <==
/*
    This file is part of the iText (R) project.
    Copyright (c) 1998-2024 Apryse Group NV
    Authors: Apryse Software.

    This program is offered under a commercial and under the AGPL license.
    For commercial licensing, contact us at https://itextpdf.com/sales.  For AGPL licensing, see below.

    AGPL licensing:
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
package com.itextpdf.layout.layout;

import com.itextpdf.kernel.geom.Rectangle;

/**
 * Represents the root layout area.
 */
public class RootLayoutArea extends LayoutArea implements Cloneable {
    /**
     * Indicates whether the area already has some placed content or not.
     */
    protected boolean emptyArea = true;

    /**
     * Creates the root layout area.
     *
     * @param pageNumber the value number of page
     * @param bBox the bounding box
     */
    public RootLayoutArea(int pageNumber, Rectangle bBox) {
        super(pageNumber, bBox);
    }

    /**
     * Indicates whether the area already has some placed content or not.
     *
     * @return whether the area is empty or not
     */
    public boolean isEmptyArea() {
        return emptyArea;
    }

    /**
     * Defines whether the area already has some placed content or not.
     *
     * @param emptyArea indicates whether the area already has some placed content or not.
     */
    public void setEmptyArea(boolean emptyArea) {
        this.emptyArea = emptyArea;
    }

    /**
     * Creates a "deep copy" of this RootLayoutArea, meaning the object returned by this method will be independent
     * of the object being cloned.
     * Note that although the return type of this method is {@link LayoutArea},
     * the actual type of the returned object is {@link RootLayoutArea}.
     *
     * @return the copied RootLayoutArea.
     */
    @Override
    public LayoutArea clone() {
        RootLayoutArea area = (RootLayoutArea) super.clone();
        area.setEmptyArea(emptyArea);
        return area;
    }
}
